/*
   net/netplayer.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include <string>

#include "core/netplayer.h"
#include "sys/sys.h"

namespace core
{

NetPlayer::NetPlayer(NetClient *client) : Player()
{

	player_client = client;
}

NetPlayer::~NetPlayer()
{
}

void NetPlayer::sound(const std::string name)
{
	std::string msg("msg snd ");
	msg.append(name);
	msg += '\n';

	player_client->send_raw(msg);
}

void NetPlayer::message(const Message::Channel channel, const std::string text)
{
	if (!text.size())
		return;

	std::string msg_channel;
	switch (channel) {
		case core::Message::Info:	// Info message
			msg_channel.assign("info");
			break;

		case core::Message::Local:	// Chat message in the local zone
			msg_channel.assign("local");
			break;

		case core::Message::Public:	// Public chat message
			msg_channel.assign("public");
			break;

		case core::Message::Private:	// Private chat message
			msg_channel.assign("private");
			break;

		case core::Message::RCon:	// RCon message
			msg_channel.assign("rcon");
			break;

		default:
			con_warn << "message on unknown channel " << channel << "!" << std::endl;
			return;
			break;
	}

	std::string msg("msg ");
	msg.append(msg_channel);
	msg += ' ';
	msg.append(text);
	msg += '\n';

	player_client->send_raw(msg);
}

}
