/*
   ui/paint.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_UI_PAINT_H__
#define __INCLUDED_UI_PAINT_H__

#include "ui/widget.h"

namespace ui
{

/// low-level widget paint functions
namespace paint
{

/// assign system colors
void assign_color(const char c, const math::Color &color);

/// set paint color
void color(float r = 0.0f, float g = 0.0f, float b = 0.0f, float a = 1.0f);

/// set paint color
void color(math::Color const & color);

/// set paint color
void color_code(const char c);

/// draw a border
void border(const math::Vector2f &location, const math::Vector2f &size);

/// draw a rectangle
void rectangle(const math::Vector2f &location, const math::Vector2f &size);

/// draw a rectangular bitmap
void bitmap(const math::Vector2f &location, const math::Vector2f &size, std::string const &texture);

/// draw aligned text
void label(const math::Vector2f &location, const math::Vector2f &size, const Font *font, const std::string &text, unsigned int align = AlignCenter);

/// draw unaligned text
void text(const math::Vector2f &location, const math::Vector2f &size, const Font *font, const std::string &text);

/// draw unaligned text
void text(const math::Vector2f &location, const math::Vector2f &size, const Font *font, std::stringstream & textstream);

}

}

#endif // __INCLUDED_UI_PAINT_H__

